This function first checks the input parameters. It then constructs the output file names and the command to run the perl script.
The command is executed using the system function. If the 'verbose' parameter is set to TRUE, the function will print a message
when it has finished running.
The perl script was written by Doug Scofield, see references.